@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.23.0 2022-09-04
+ * @version CYBOP 0.24.0 2022-12-24
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -50,22 +50,24 @@
  * @param p5 the destination index
  * @param p6 the source index
  * @param p7 the adjust count flag
- * @param p8 the operation type
- * @param p9 the destination part item index
- * @param p10 the source part item index
- * @param p11 the source part
- * @param p12 the source type
+ * @param p8 the repetition number for "modify/repeat"
+ * @param p9 the searchterm data for "modify/replace"
+ * @param p10 the searchterm count for "modify/replace"
+ * @param p11 the operation type
+ * @param p12 the destination part item index
+ * @param p13 the source part item index
+ * @param p14 the source part
+ * @param p15 the source type
  */
-void apply_modify_type(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12) {
+void apply_modify_type(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12, void* p13, void* p14, void* p15) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply modify type.");
-
-    //?? fwprintf(stdout, L"Debug: Apply modify type. Destination type: %i. Source type: %i.\n", *((int*) p2), *((int*) p12));
+    //?? fwprintf(stdout, L"Debug: Apply modify type. Destination type: %i. Source type: %i.\n", *((int*) p2), *((int*) p15));
 
     // The comparison result.
     int r = *FALSE_BOOLEAN_STATE_CYBOI_MODEL;
 
-    compare_integer_equal((void*) &r, p2, p12);
+    compare_integer_equal((void*) &r, p2, p15);
 
     if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
@@ -73,13 +75,21 @@ void apply_modify_type(void* p0, void* p1, void* p2, void* p3, void* p4, void* p
         // The destination- and source type are identical.
         //
 
-        apply_modify_deep(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11);
+        apply_modify_deep(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12, p13, p14);
 
     } else {
 
-        log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not apply modify type. The destination type and source type are different.");
-        fwprintf(stdout, L"Error: Could not apply modify type. The destination type and source type are different.\n");
-        fwprintf(stdout, L"Error: Destination type: %i. Source type: %i.\n", *((int*) p2), *((int*) p12));
+        //
+        // CAUTION! Comment out this error message since it may be normal behaviour
+        // that one part does not exist. When applying an identical algorithm to
+        // different data structures, then some child nodes may not exist.
+        // However, in this case it is WANTED behaviour in order to reuse the
+        // algorithm for different tree structures. Therefore, IGNORE this error.
+        //
+        // log_message_terminated((void*) ERROR_LEVEL_LOG_CYBOI_MODEL, (void*) L"Could not apply modify type. The destination type and source type are different.");
+        // fwprintf(stdout, L"Error: Could not apply modify type. The destination type and source type are different.\n");
+        // fwprintf(stdout, L"Error: Destination type: %i. Source type: %i.\n", *((int*) p2), *((int*) p15));
+        //
     }
 }
 
