@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.23.0 2022-09-04
+ * @version CYBOP 0.24.0 2022-12-24
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -45,35 +45,26 @@
 // access
 //
 
-/** The channel get access logic cyboi format. */
-static int* CHANNEL_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1000_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 /** The count access logic cyboi format. */
-static int* COUNT_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1001_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* COUNT_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1000_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The empty indicate access logic cyboi format. */
-static int* EMPTY_INDICATE_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1002_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The encoding get access logic cyboi format. */
-static int* ENCODING_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1003_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* EMPTY_INDICATE_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1001_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The exists indicate access logic cyboi format. */
-static int* EXISTS_INDICATE_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1004_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* EXISTS_INDICATE_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1002_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The format get access logic cyboi format. */
-static int* FORMAT_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1005_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* FORMAT_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1003_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The get index access logic cyboi format. */
-static int* GET_INDEX_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1006_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
-/** The language get access logic cyboi format. */
-static int* LANGUAGE_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1007_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* GET_INDEX_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1004_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The name get access logic cyboi format. */
-static int* NAME_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1008_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* NAME_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1005_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The type get access logic cyboi format. */
-static int* TYPE_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1009_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* TYPE_GET_ACCESS_LOGIC_CYBOI_FORMAT = NUMBER_1006_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
 // activate
@@ -188,8 +179,8 @@ static int* CHANGE_PERMISSION_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1307_INTEGER_S
 /** The word count command logic cyboi format. */
 static int* WORD_COUNT_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1308_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The create folder command logic cyboi format. */
-static int* CREATE_FOLDER_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1309_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+/** The create directory command logic cyboi format. */
+static int* CREATE_DIRECTORY_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1309_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The ping command logic cyboi format. */
 static int* PING_COMMAND_LOGIC_CYBOI_FORMAT = NUMBER_1310_INTEGER_STATE_CYBOI_MODEL_ARRAY;
@@ -332,17 +323,14 @@ static int* UNEQUAL_COMPARE_LOGIC_CYBOI_FORMAT = NUMBER_1505_INTEGER_STATE_CYBOI
 // contain
 //
 
-/** The both contain logic cyboi format. */
-static int* BOTH_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1550_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+/** The any contain logic cyboi format. */
+static int* ANY_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1550_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The left contain logic cyboi format. */
 static int* LEFT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1551_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The none contain logic cyboi format. */
-static int* NONE_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1552_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 /** The right contain logic cyboi format. */
-static int* RIGHT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1553_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* RIGHT_CONTAIN_LOGIC_CYBOI_FORMAT = NUMBER_1552_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
 // convert
@@ -477,9 +465,6 @@ static int* DESTROY_MEMORISE_LOGIC_CYBOI_FORMAT = NUMBER_2201_INTEGER_STATE_CYBO
 /** The append modify logic cyboi format. */
 static int* APPEND_MODIFY_LOGIC_CYBOI_FORMAT = NUMBER_2300_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The concatenate modify logic cyboi format. */
-static int* CONCATENATE_MODIFY_LOGIC_CYBOI_FORMAT = NUMBER_2301_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 /** The empty modify logic cyboi format. */
 static int* EMPTY_MODIFY_LOGIC_CYBOI_FORMAT = NUMBER_2302_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
