@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.23.0 2022-09-04
+ * @version CYBOP 0.24.0 2022-12-24
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -41,7 +41,7 @@
 #include "../../applicator/command/compare_files.c"
 #include "../../applicator/command/config_network.c"
 #include "../../applicator/command/copy_file.c"
-#include "../../applicator/command/create_folder.c"
+#include "../../applicator/command/create_directory.c"
 #include "../../applicator/command/date.c"
 #include "../../applicator/command/delay.c"
 #include "../../applicator/command/diff.c"
@@ -141,16 +141,6 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
     // access
     //
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p8, (void*) CHANNEL_GET_ACCESS_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_get(p0, p1, p3, p4, p2, (void*) CHANNEL_GET_ACCESS_LOGIC_CYBOI_FORMAT);
-        }
-    }
-
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         compare_integer_equal((void*) &r, p8, (void*) COUNT_ACCESS_LOGIC_CYBOI_FORMAT);
@@ -171,16 +161,6 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
         }
     }
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p8, (void*) ENCODING_GET_ACCESS_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_get(p0, p1, p3, p4, p2, (void*) ENCODING_GET_ACCESS_LOGIC_CYBOI_FORMAT);
-        }
-    }
-
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         compare_integer_equal((void*) &r, p8, (void*) EXISTS_INDICATE_ACCESS_LOGIC_CYBOI_FORMAT);
@@ -211,16 +191,6 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
         }
     }
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p8, (void*) LANGUAGE_GET_ACCESS_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_get(p0, p1, p3, p4, p2, (void*) LANGUAGE_GET_ACCESS_LOGIC_CYBOI_FORMAT);
-        }
-    }
-
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         compare_integer_equal((void*) &r, p8, (void*) NAME_GET_ACCESS_LOGIC_CYBOI_FORMAT);
@@ -548,11 +518,11 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        compare_integer_equal((void*) &r, p8, (void*) CREATE_FOLDER_COMMAND_LOGIC_CYBOI_FORMAT);
+        compare_integer_equal((void*) &r, p8, (void*) CREATE_DIRECTORY_COMMAND_LOGIC_CYBOI_FORMAT);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-            apply_create_folder(p0, p1, p3, p4, p2);
+            apply_create_directory(p0, p1, p3, p4, p2);
         }
     }
 
@@ -1024,11 +994,11 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
 
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-        compare_integer_equal((void*) &r, p8, (void*) BOTH_CONTAIN_LOGIC_CYBOI_FORMAT);
+        compare_integer_equal((void*) &r, p8, (void*) ANY_CONTAIN_LOGIC_CYBOI_FORMAT);
 
         if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
-            apply_calculate(p0, p1, p3, p4, p2, (void*) BOTH_CONTAIN_LOGIC_CYBOI_FORMAT);
+            apply_calculate(p0, p1, p3, p4, p2, (void*) ANY_CONTAIN_LOGIC_CYBOI_FORMAT);
         }
     }
 
@@ -1042,16 +1012,6 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
         }
     }
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p8, (void*) NONE_CONTAIN_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_calculate(p0, p1, p3, p4, p2, (void*) NONE_CONTAIN_LOGIC_CYBOI_FORMAT);
-        }
-    }
-
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         compare_integer_equal((void*) &r, p8, (void*) RIGHT_CONTAIN_LOGIC_CYBOI_FORMAT);
@@ -1413,16 +1373,6 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
         }
     }
 
-    if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-        compare_integer_equal((void*) &r, p8, (void*) CONCATENATE_MODIFY_LOGIC_CYBOI_FORMAT);
-
-        if (r != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
-
-            apply_modify(p0, p1, p3, p4, p2, (void*) CONCATENATE_MODIFY_LOGIC_CYBOI_FORMAT);
-        }
-    }
-
     if (r == *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {
 
         compare_integer_equal((void*) &r, p8, (void*) EMPTY_MODIFY_LOGIC_CYBOI_FORMAT);
