@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.23.0 2022-09-04
+ * @version CYBOP 0.24.0 2022-12-24
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -44,8 +44,8 @@
 void deserialise_binary_crlf_termination(void* p0, void* p1, void* p2) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Deserialise binary crlf termination.");
-    fwprintf(stdout, L"Debug: Deserialise binary crlf termination. source message count p2: %i\n", p2);
-    fwprintf(stdout, L"Debug: Deserialise binary crlf termination. source message count *p2: %i\n", *((int*) p2));
+    //?? fwprintf(stdout, L"Debug: Deserialise binary crlf termination. source message count p2: %i\n", p2);
+    //?? fwprintf(stdout, L"Debug: Deserialise binary crlf termination. source message count *p2: %i\n", *((int*) p2));
 
     // The source data position.
     void* d = *NULL_POINTER_STATE_CYBOI_MODEL;
