@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.23.0 2022-09-04
+ * @version CYBOP 0.24.0 2022-12-24
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -31,7 +31,7 @@
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 #include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/representer/serialiser/xml/element_part_xml_serialiser.c"
+#include "../../../../executor/representer/serialiser/xml/element_xml_serialiser.c"
 #include "../../../../logger/logger.c"
 
 /**
@@ -40,11 +40,18 @@
  * @param p0 the destination item
  * @param p1 the source model data
  * @param p2 the source model count
- * @param p3 the indentation flag
- * @param p4 the indentation level
- * @param p5 the void flag
+ * @param p3 the sign flag
+ * @param p4 the number base
+ * @param p5 the classic octal prefix flag (true means 0 as in c/c++; false means modern style 0o as in perl and python)
+ * @param p6 the decimal separator data
+ * @param p7 the decimal separator count
+ * @param p8 the decimal places
+ * @param p9 the scientific notation flag
+ * @param p10 the indentation flag
+ * @param p11 the indentation level
+ * @param p12 the void flag
  */
-void serialise_xml_part(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
+void serialise_xml_part(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10, void* p11, void* p12) {
 
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Serialise xml part.");
 
@@ -77,7 +84,7 @@ void serialise_xml_part(void* p0, void* p1, void* p2, void* p3, void* p4, void*
             break;
         }
 
-        serialise_xml_part_element(p0, p1, (void*) &j, p3, p4, p5);
+        serialise_xml_element(p0, p1, (void*) &j, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12);
 
         // Increment loop variable.
         j++;
